@@ -532,10 +532,12 @@ class TextBox:
         text_len = len(text)
         while text:
             i = 1
-            while self.font.size(text[:i])[0] < self.rect.w and i < text_len:
+            while self.font.size(text[:i])[0] < self.rect.w - self.padding.x * 2 and i < text_len:
                 i += 1
             if i < text_len:
-                i = text.rfind(' ', 0, i) + 1
+                new_i = text.rfind(' ', 0, i) + 1 # attempt to find the farthest space
+                if new_i: # space is found
+                    i = new_i # use found index for word wrappign
             screen.blit(
                 self.font.render(text[:i], True, self.text_color),
                 (self.rect.x + self.padding.x, self.rect.y + self.padding.y + y)
@@ -550,3 +552,56 @@ class TextBox:
         self.text_index += 1
         if self.text_index >= self.text_arr_size:
             self.done = True
+
+class InputBox(TextBox):
+    '''
+    A TextBox that updates with input taken
+    '''
+    def __init__(
+            self,
+            rect: pygame.Rect,
+            bg_color: pygame.Color = 'grey',
+            text_color: pygame.Color = 'black',
+            border_radius: int = 10,
+            padding: Point = None,
+            font: pygame.font.Font = None
+        ):
+        super().__init__(
+            [''],
+            rect,
+            bg_color,
+            text_color,
+            border_radius,
+            padding,
+            font,
+        )
+
+    def update(self, event: pygame.event.Event):
+        '''
+        this will update the text with an appropriately depending on the key pressed
+        :event: the KEYDOWN event to be evaluated
+        '''
+        if event.type != KEYDOWN:
+            return
+        match event.unicode.lower():
+            case '\r': # enter
+                self.done = True
+            case '\x08': # backspace
+                self.text[0] = self.text[0][:-1]
+            case _:
+                self.text[0] += event.unicode
+
+    def reset(self):
+        '''
+        reset the text to be blank again
+        '''
+        self.done = False
+        self.text[0] = ''
+        self.text_index = 0
+
+    def get_value(self) -> str:
+        '''
+        get the value of the text entered
+        :returns: the text entered
+        '''
+        return self.text[0]
